<?php
if(!defined('sugarEntry') || !sugarEntry) die('Not A Valid Entry Point');

class ExternalCollegeStatsAPI extends SugarApi
{
	public function registerApiRest()
    {
        return array(
            //GET & POST
            'ExternalCollegeStats' => array(
                //request type
                'reqType' => array('GET','POST'),

                //set authentication
                'noLoginRequired' => false,

                //endpoint path will equal External/CollegeStats/{variable}
                'path' => array('External', 'CollegeStats', '?'),

                //endpoint variables. to access the last value in the url, we will use "state"
                'pathVars' => array('', '', 'state'),

                //method to call
                'method' => 'CallExternal',

                //short help string to be displayed in the help documentation
                'shortHelp' => 'Calls external API located at api.data.gov/ed/collegescorecard',

                //long help to be displayed in the help documentation
                'longHelp' => 'custom/clients/base/api/help/ExternalCollegeStats_help.html',
            ),
        );
    }

    /**
     * Method to be used for External/CollegeStats/{state} endpoint
     */
    public function CallExternal($api, $args)
    {

    	// key obtained by registering at https://api.data.gov/signup/
	    $api_key = "XXXXXXXyour-real-key-goes-hereXXXXXXX";

	    // we will use the college scorecard APi endpoints
	    $base_url = "https://api.data.gov/ed/collegescorecard/v1/schools";

	    // no whitespace in the "fields" value but must be a string of comma-delimited values dictating which fields we would like to be returned
	    // for now, not interested in paging the data so simply set the per_page value to 50
		$data = array(
			'api_key' => $api_key,
			'per_page' => 50,
			'fields' => 'school.name,school.school_url,school.city,school.state,id,latest.aid.median_debt.completers.overall,latest.repayment.1_yr_repayment.completers,latest.earnings.10_yrs_after_entry.working_not_enrolled.mean_earnings,latest.cost.tuition.out_of_state,latest.cost.tuition.in_state'
		);

		// check if a state value is requested. if it is set to "all", don't send a value. this is the endpoint's default
		if ( isset($args['state']) && !empty($args['state']) && $args['state'] != "all" ) {
			$data['school.state'] = $args['state'];
		}

		// call the external endpoint using curl
		$ch = curl_init();
		$query = http_build_query($data);
		$url = $base_url . '?' . $query;
		curl_setopt($ch, CURLOPT_URL, $url);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, true); 
		curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
		$result = curl_exec($ch);

		if ( $result !== false ) {
	            $response->success = true;
	            $response->body = $result;
	    } else {
	            $response->success = false;
	            $response->body = curl_error($ch);
	            $response->error = curl_errno($ch);
	    }
	    curl_close($ch);                                      
	    return $response;
    }
}
